# cffi_glpk
* CFFI bindings for GLPK
* Build for GLPK 4.65, may or may not work for other versions.
* Usage :
  * Briefly: from glpk_cffi import lib, ffi
  * See example/example.py complete example
  * Note import is glpk_cffi NOT cffi_glpk!!!